from .version import version as __version__

from . import _init_rev

# autogenerated by 'robotpy-build create-imports rev'
from ._rev import (
    AnalogInput,
    CANSensor,
    CANSparkMax,
    CANSparkMaxLowLevel,
    CIEColor,
    ColorMatch,
    ColorSensorV3,
    MotorFeedbackSensor,
    REVLibError,
    RelativeEncoder,
    SparkMaxAlternateEncoder,
    SparkMaxAnalogSensor,
    SparkMaxLimitSwitch,
    SparkMaxPIDController,
    SparkMaxRelativeEncoder,
)

__all__ = [
    "AnalogInput",
    "CANSensor",
    "CANSparkMax",
    "CANSparkMaxLowLevel",
    "CIEColor",
    "ColorMatch",
    "ColorSensorV3",
    "MotorFeedbackSensor",
    "REVLibError",
    "RelativeEncoder",
    "SparkMaxAlternateEncoder",
    "SparkMaxAnalogSensor",
    "SparkMaxLimitSwitch",
    "SparkMaxPIDController",
    "SparkMaxRelativeEncoder",
]

del _init_rev



#!/usr/bin/env python3

# Copyright (c) 2017-2018 FIRST. All Rights Reserved.
# Open Source Software - may be modified and shared by FRC teams. The code
# must be accompanied by the FIRST BSD license file in the root directory of
# the project.

import wpilib
from rev import ColorSensorV3, ColorMatch


class MyRobot(wpilib.TimedRobot):
    """
    This is a simple example to show the values that can be read from the REV
    Color Sensor V3
    """

    def robotInit(self):
        self.colorSensor = ColorSensorV3(wpilib.I2C.Port.kOnboard)

        # A Rev Color Match object is used to register and detect known colors. This can
        # be calibrated ahead of time or during operation.
        #
        # This object uses a simple euclidian distance to estimate the closest match
        # with given confidence range.
        self.colorMatcher = ColorMatch()

        # Note: Any example colors should be calibrated as the user needs, these
        # are here as a basic example.
        self.blueTarget = wpilib.Color(0.143, 0.427, 0.429)
        self.greenTarget = wpilib.Color(0.197, 0.561, 0.240)
        self.redTarget = wpilib.Color(0.561, 0.232, 0.114)
        self.yellowTarget = wpilib.Color(0.361, 0.524, 0.113)

        self.colorMatcher.addColorMatch(self.blueTarget)
        self.colorMatcher.addColorMatch(self.greenTarget)
        self.colorMatcher.addColorMatch(self.redTarget)
        self.colorMatcher.addColorMatch(self.yellowTarget)

    def robotPeriodic(self):

        # The method GetColor() returns a normalized color value from the sensor and can be
        # useful if outputting the color to an RGB LED or similar. To
        # read the raw color, use GetRawColor().

        # The color sensor works best when within a few inches from an object in
        # well lit conditions (the built in LED is a big help here!). The farther
        # an object is the more light from the surroundings will bleed into the
        # measurements and make it difficult to accurately determine its color.
        detectedColor = self.colorSensor.getColor()

        # Run the color match algorithm on our detected color. The confidence
        # specifies how close the detectedColor has to be to one of your colors
        # for it to match.
        match, confidence = self.colorMatcher.matchClosestColor(detectedColor)

        colorString = ""

        if match == self.blueTarget:
            colorString = "Blue"
        elif match == self.redTarget:
            colorString = "Red"
        elif match == self.greenTarget:
            colorString = "Green"
        elif match == self.yellowTarget:
            colorString = "Yellow"
        else:  # match is black
            colorString = "Unknown"

        # Open Smart Dashboard or Shuffleboard to see the color detected by the
        # sensor.
        wpilib.SmartDashboard.putNumber("Red", detectedColor.red)
        wpilib.SmartDashboard.putNumber("Green", detectedColor.green)
        wpilib.SmartDashboard.putNumber("Blue", detectedColor.blue)
        wpilib.SmartDashboard.putNumber("Confidence", confidence)
        wpilib.SmartDashboard.putString("Detected Color", colorString)


if __name__ == "__main__":
    wpilib.run(MyRobot)



#!/usr/bin/env python3

# Copyright (c) 2017-2018 FIRST. All Rights Reserved.
# Open Source Software - may be modified and shared by FRC teams. The code
# must be accompanied by the FIRST BSD license file in the root directory of
# the project.

import wpilib
from rev import ColorSensorV3


class MyRobot(wpilib.TimedRobot):
    """
    This is a simple example to show the values that can be read from the REV
    Color Sensor V3
    """

    def robotInit(self):
        self.colorSensor = ColorSensorV3(wpilib.I2C.Port.kOnboard)

    def robotPeriodic(self):

        # The method getColor() returns a normalized color value from the sensor and can be
        # useful if outputting the color to an RGB LED or similar. To
        # read the raw color, use getRawColor().

        # The color sensor works best when within a few inches from an object in
        # well lit conditions (the built in LED is a big help here!). The farther
        # an object is the more light from the surroundings will bleed into the
        # measurements and make it difficult to accurately determine its color.
        detectedColor = self.colorSensor.getColor()

        # The sensor returns a raw IR value of the infrared light detected.
        ir = self.colorSensor.getIR()

        # Open Smart Dashboard or Shuffleboard to see the color detected by the
        # sensor.
        wpilib.SmartDashboard.putNumber("Red", detectedColor.red)
        wpilib.SmartDashboard.putNumber("Green", detectedColor.green)
        wpilib.SmartDashboard.putNumber("Blue", detectedColor.blue)
        wpilib.SmartDashboard.putNumber("IR", ir)

        # In addition to RGB IR values, the color sensor can also return an
        # infrared proximity value. The chip contains an IR led which will emit
        # IR pulses and measure the intensity of the return. When an object is
        # close the value of the proximity will be large (max 2047 with default
        # settings) and will approach zero when the object is far away.
        #
        # Proximity can be used to roughly approximate the distance of an object
        # or provide a threshold for when an object is close enough to provide
        # accurate color values.
        proximity = self.colorSensor.getProximity()

        wpilib.SmartDashboard.putNumber("Proximity", proximity)

        # `self.colorSensor.getColor()` returns a Color that is normalized.
        # The R, G, B values are scaled so that they add up to 1.
        # (`red + green + blue = 1`).
        # `.getRawColor()` will return color data that is easier to
        # visualize but may be harder to use effectively in your code.

        rawDetectedColor = self.colorSensor.getRawColor()

        wpilib.SmartDashboard.putNumber("Raw Red", rawDetectedColor.red)
        wpilib.SmartDashboard.putNumber("Raw Green", rawDetectedColor.green)
        wpilib.SmartDashboard.putNumber("Raw Blue", rawDetectedColor.blue)
        wpilib.SmartDashboard.putNumber("Raw IR", rawDetectedColor.ir)


if __name__ == "__main__":
    wpilib.run(MyRobot)
